apk-launcher
============================================================
| APK Reinstall -> Start Activity -> Logcat

.. code:: sh

  $ pip install apk-launcher --global-option=build_ext --global-option="-L/usr/local/opt/openssl/lib" --global-option="-I/usr/local/opt/openssl/include"
  $ apk-launcher {APK_PATH}

